summary refs log tree commit diff
path: root/pkgs/lib/misc.nix
diff options
context:
space:
mode:
authorMarc Weber <marco-oweber@gmx.de>2009-05-24 10:57:41 +0000
committerMarc Weber <marco-oweber@gmx.de>2009-05-24 10:57:41 +0000
commitf7f938a1d15277fa11a2cbf75fe9c7d4344f25c3 (patch)
tree7f0728120b23ae097a4259c62839037bd84aebad /pkgs/lib/misc.nix
parent62620f0411b4ada733ae4e701416997140053762 (diff)
downloadnixpkgs-f7f938a1d15277fa11a2cbf75fe9c7d4344f25c3.tar
nixpkgs-f7f938a1d15277fa11a2cbf75fe9c7d4344f25c3.tar.gz
nixpkgs-f7f938a1d15277fa11a2cbf75fe9c7d4344f25c3.tar.bz2
nixpkgs-f7f938a1d15277fa11a2cbf75fe9c7d4344f25c3.tar.lz
nixpkgs-f7f938a1d15277fa11a2cbf75fe9c7d4344f25c3.tar.xz
nixpkgs-f7f938a1d15277fa11a2cbf75fe9c7d4344f25c3.tar.zst
nixpkgs-f7f938a1d15277fa11a2cbf75fe9c7d4344f25c3.zip
big breaking change: renaming lib.getAttr to lib.attrByPath
getAttr was ambiguous. It's also a builtin function

fix

svn path=/nixpkgs/trunk/; revision=15692
Diffstat (limited to 'pkgs/lib/misc.nix')
-rw-r--r--pkgs/lib/misc.nix8
1 files changed, 4 insertions, 4 deletions
diff --git a/pkgs/lib/misc.nix b/pkgs/lib/misc.nix
index b8e49bad977..d515158c00a 100644
--- a/pkgs/lib/misc.nix
+++ b/pkgs/lib/misc.nix
@@ -111,7 +111,7 @@ rec {
   pairMap = innerPairMap [];
 
   
   # shortcut for getAttr ["name"] default attrs
   maybeAttr = name: default: attrs:
     if (__hasAttr name attrs) then (__getAttr name attrs) else default;
 
@@ -131,14 +131,14 @@ rec {
   checkFlag = attrSet: name:
 	if (name == "true") then true else
 	if (name == "false") then false else
-	if (elem name (getAttr ["flags"] [] attrSet)) then true else
-	getAttr [name] false attrSet ;
+	if (elem name (attrByPath ["flags"] [] attrSet)) then true else
+	attrByPath [name] false attrSet ;
 
 
   # Input : attrSet, [ [name default] ... ], name
   # Output : its value or default.
   getValue = attrSet: argList: name:
-  ( getAttr [name] (if checkFlag attrSet name then true else
+  ( attrByPath [name] (if checkFlag attrSet name then true else
 	if argList == [] then null else
 	let x = builtins.head argList; in
 		if (head x) == name then
@@ -111,7 +111,7 @@ rec {
 
   
-  # shortcut for getAttr ["name"] default attrs
+  # shortcut for attrByPath ["name"] default attrs
   maybeAttr = name: default: attrs:
     if (__hasAttr name attrs) then (__getAttr name attrs) else default;